<?php

namespace Litecms\Sponserbonus\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Sponserbonus\Models\Sponserbonus;

class SponserbonusPolicy
{

    /**
     * Determine if the given user can view the sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sponserbonus $sponserbonus)
    {
        if ($user->canDo('sponserbonus.sponserbonus.view') && $user->isAdmin()) {
            return true;
        }

        return $sponserbonus->user_id == user_id() && $sponserbonus->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sponserbonus.sponserbonus.create');
    }

    /**
     * Determine if the given user can update the given sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sponserbonus $sponserbonus)
    {
        if ($user->canDo('sponserbonus.sponserbonus.edit') && $user->isAdmin()) {
            return true;
        }

        return $sponserbonus->user_id == user_id() && $sponserbonus->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sponserbonus $sponserbonus)
    {
        return $sponserbonus->user_id == user_id() && $sponserbonus->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sponserbonus $sponserbonus)
    {
        if ($user->canDo('sponserbonus.sponserbonus.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sponserbonus.
     *
     * @param UserPolicy $user
     * @param Sponserbonus $sponserbonus
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sponserbonus $sponserbonus)
    {
        if ($user->canDo('sponserbonus.sponserbonus.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
